<?php

/**
 * @file
 * Whiteboard admin file for validating and specifying form texbar data
 */

/**
 * Form API callback to validate the upload settings form.
 */
function texbar_admin_settings_validate($form, &$form_state) {
  $size = $form_state['values']['texbar_size'];

  $path = file_exists($_SERVER['DOCUMENT_ROOT'] . base_path() . '/' . $form_state['values']['texbar_markitup_path']);

  $path2 = file_exists($_SERVER['DOCUMENT_ROOT'] . base_path() . '/' . $form_state['values']['output_path']);

  $path3 = file_exists($form_state['values']['html2ps_path']);

  $path4 = file_exists($form_state['values']['ps2pdf_path']);

  if (!is_numeric($size) || ($size <= 0)) {
    form_set_error('texbar_size', t('The texbar size limit must be a number and greater than zero.'));
  }
  if (!$path) {
    form_set_error('texbar_markitup_path', t('markItUp library not found.'));
  }

  if (!$path2) {
    form_set_error('output_path', t('Output path not found.'));
  }

  if (!$path3) {
    form_set_error('html2ps_path', t('html2ps not found.'));
  }
  if (!$path4) {
    form_set_error('ps2pdf_path', t('ps2pdf not found.'));
  }
}

/**
 * Menu callback for the upload settings form.
 */
function texbar_admin_settings($form, &$form_state) {

  $form['settings_general'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
    '#collapsible' => TRUE,
  );
  $form['settings_general']['texbar_size'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum number of characters'),
    '#default_value' => check_plain(variable_get('texbar_size', 50000)),
    '#size' => 8,
    '#maxlength' => 8,
    '#description' => t('The maximum number of characters a user can convert to PDF.'),
    '#field_suffix' => t('characters'),
  );

  $form['settings_general']['html2ps_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to html2ps'),
    '#default_value' => check_plain(variable_get('html2ps_path', '/usr/bin/html2ps')),
    '#size' => 50,
    '#maxlength' => 50,
    '#description' => t('Absolute path to the binary html2ps.'),
    '#field_suffix' => t(''),
  );

  $form['settings_general']['ps2pdf_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to ps2pdf'),
    '#default_value' => check_plain(variable_get('ps2pdf_path', '/usr/bin/ps2pdf')),
    '#size' => 50,
    '#maxlength' => 50,
    '#description' => t('Absolute path to the binary ps2pdf'),
    '#field_suffix' => t(''),
  );

  $form['settings_general']['output_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to save output'),
    '#default_value' => check_plain(variable_get('output_path', '')),
    '#size' => 50,
    '#maxlength' => 50,
    '#description' => t('The Drupal relative path to save output to(must be accessible from the web.)'),
    '#field_suffix' => t(''),
  );

  $form['settings_general']['texbar_markitup_path'] = array(
    '#type' => 'textfield',
    '#title' => t('markItUp path'),
    '#default_value' => check_plain(variable_get('texbar_markitup_path', 'sites/all/libraries/markitup/markitup/jquery.markitup.js')),
    '#size' => '50',
    '#maxlength' => '150',
    '#description' => t('The Drupal relative path to the markItUp library including filename. Recommended setting is prepopulated.'),
  );

  $form['settings_general']['mimetex_path'] = array(
    '#type' => 'textfield',
    '#title' => t('mimeTex URL path'),
    '#default_value' => check_plain(variable_get('mimetex_path', 'http://')),
    '#size' => '50',
    '#maxlength' => '150',
    '#description' => t('Full URL path to mimetex CGI script.'),
  );

  $form['#validate'][] = 'texbar_admin_settings_validate';

  return system_settings_form($form);
}

